==> jc-1.4.0.tar.gz: javax/accessibility/AccessibleState.h <==
// public class javax.accessibility.AccessibleState

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 31af68d307de0dce javax_accessibility_AccessibleBundle
// @dep_class 90b59e82f2b6bf28 javax_accessibility_AccessibleState

// header file dependencies
// @dep_header javax_accessibility_AccessibleBundle

#include "javax/accessibility/AccessibleBundle.h"

#ifndef _JC_javax_accessibility_AccessibleState_H_
#define _JC_javax_accessibility_AccessibleState_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleState$object;

// Typedefs
typedef struct _jc_javax_accessibility_AccessibleState$sub_refs	_jc_javax_accessibility_AccessibleState$sub_refs;
typedef struct _jc_javax_accessibility_AccessibleState$sub_nonrefs	_jc_javax_accessibility_AccessibleState$sub_nonrefs;
typedef struct _jc_javax_accessibility_AccessibleState$refs	_jc_javax_accessibility_AccessibleState$refs;
typedef struct _jc_javax_accessibility_AccessibleState$nonrefs	_jc_javax_accessibility_AccessibleState$nonrefs;
typedef struct _jc_javax_accessibility_AccessibleState$object	_jc_javax_accessibility_AccessibleState$object;

typedef struct _jc_javax_accessibility_AccessibleState$fields_struct	_jc_javax_accessibility_AccessibleState$fields_struct;
typedef const struct _jc_javax_accessibility_AccessibleState$vmethods	_jc_javax_accessibility_AccessibleState$vmethods;
typedef const struct _jc_javax_accessibility_AccessibleState$vtable	_jc_javax_accessibility_AccessibleState$vtable;
typedef const struct _jc_javax_accessibility_AccessibleState$vtype	_jc_javax_accessibility_AccessibleState$vtype;

// Class fields structure
struct _jc_javax_accessibility_AccessibleState$fields_struct {
	struct _jc_javax_accessibility_AccessibleState$object	*ACTIVE;
	struct _jc_javax_accessibility_AccessibleState$object	*ARMED;
	struct _jc_javax_accessibility_AccessibleState$object	*BUSY;
	struct _jc_javax_accessibility_AccessibleState$object	*CHECKED;
	struct _jc_javax_accessibility_AccessibleState$object	*COLLAPSED;
	struct _jc_javax_accessibility_AccessibleState$object	*EDITABLE;
	struct _jc_javax_accessibility_AccessibleState$object	*ENABLED;
	struct _jc_javax_accessibility_AccessibleState$object	*EXPANDABLE;
	struct _jc_javax_accessibility_AccessibleState$object	*EXPANDED;
	struct _jc_javax_accessibility_AccessibleState$object	*FOCUSABLE;
	struct _jc_javax_accessibility_AccessibleState$object	*FOCUSED;
	struct _jc_javax_accessibility_AccessibleState$object	*HORIZONTAL;
	struct _jc_javax_accessibility_AccessibleState$object	*ICONIFIED;
	struct _jc_javax_accessibility_AccessibleState$object	*MODAL;
	struct _jc_javax_accessibility_AccessibleState$object	*MULTISELECTABLE;
	struct _jc_javax_accessibility_AccessibleState$object	*MULTI__5fLINE;
	struct _jc_javax_accessibility_AccessibleState$object	*OPAQUE;
	struct _jc_javax_accessibility_AccessibleState$object	*PRESSED;
	struct _jc_javax_accessibility_AccessibleState$object	*RESIZABLE;
	struct _jc_javax_accessibility_AccessibleState$object	*SELECTABLE;
	struct _jc_javax_accessibility_AccessibleState$object	*SELECTED;
	struct _jc_javax_accessibility_AccessibleState$object	*SHOWING;
	struct _jc_javax_accessibility_AccessibleState$object	*SINGLE__5fLINE;
	struct _jc_javax_accessibility_AccessibleState$object	*TRANSIENT;
	struct _jc_javax_accessibility_AccessibleState$object	*VERTICAL;
	struct _jc_javax_accessibility_AccessibleState$object	*VISIBLE;
};
extern _jc_javax_accessibility_AccessibleState$fields_struct _jc_javax_accessibility_AccessibleState$class_fields;

// Constructors
extern void _jc_javax_accessibility_AccessibleState$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_accessibility_AccessibleState$object *, struct _jc_java_lang_String$object *);

// Static methods
extern void _jc_javax_accessibility_AccessibleState$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_accessibility_AccessibleState$vmethods {
};

// Vtable
struct _jc_javax_accessibility_AccessibleState$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleBundle$vmethods	javax_accessibility_AccessibleBundle;
	_jc_javax_accessibility_AccessibleState$vmethods	javax_accessibility_AccessibleState;
};

// Vtype
struct _jc_javax_accessibility_AccessibleState$vtype {
	_jc_type			type;
	_jc_javax_accessibility_AccessibleState$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleState$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_accessibility_AccessibleState$refs {
    _jc_javax_accessibility_AccessibleState$sub_refs	javax_accessibility_AccessibleState;
    _jc_javax_accessibility_AccessibleBundle$sub_refs	javax_accessibility_AccessibleBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleState$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_accessibility_AccessibleState$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleBundle$sub_nonrefs	javax_accessibility_AccessibleBundle;
    _jc_javax_accessibility_AccessibleState$sub_nonrefs	javax_accessibility_AccessibleState;
};

// Object instance structure
struct _jc_javax_accessibility_AccessibleState$object {
	_jc_javax_accessibility_AccessibleState$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_accessibility_AccessibleState$vtype	*vtype;
	_jc_javax_accessibility_AccessibleState$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_accessibility_AccessibleState$vtype _jc_javax_accessibility_AccessibleState$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_accessibility_AccessibleState, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_accessibility_AccessibleState$class_object;

#endif	/* _JC_javax_accessibility_AccessibleState_H_ */

==> jc-1.4.5.tar.gz: javax/accessibility/AccessibleState.h <==
// public class javax.accessibility.AccessibleState

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 31af68d307de0dce javax_accessibility_AccessibleBundle
// @dep_class 90b59e82f2b6bf28 javax_accessibility_AccessibleState

// header file dependencies
// @dep_header javax_accessibility_AccessibleBundle

#include "javax/accessibility/AccessibleBundle.h"

#ifndef _JC_javax_accessibility_AccessibleState_H_
#define _JC_javax_accessibility_AccessibleState_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleState$object;

// Typedefs
typedef struct _jc_javax_accessibility_AccessibleState$sub_refs	_jc_javax_accessibility_AccessibleState$sub_refs;
typedef struct _jc_javax_accessibility_AccessibleState$sub_nonrefs	_jc_javax_accessibility_AccessibleState$sub_nonrefs;
typedef struct _jc_javax_accessibility_AccessibleState$refs	_jc_javax_accessibility_AccessibleState$refs;
typedef struct _jc_javax_accessibility_AccessibleState$nonrefs	_jc_javax_accessibility_AccessibleState$nonrefs;
typedef struct _jc_javax_accessibility_AccessibleState$object	_jc_javax_accessibility_AccessibleState$object;

typedef struct _jc_javax_accessibility_AccessibleState$fields_struct	_jc_javax_accessibility_AccessibleState$fields_struct;
typedef const struct _jc_javax_accessibility_AccessibleState$vmethods	_jc_javax_accessibility_AccessibleState$vmethods;
typedef const struct _jc_javax_accessibility_AccessibleState$vtable	_jc_javax_accessibility_AccessibleState$vtable;
typedef const struct _jc_javax_accessibility_AccessibleState$vtype	_jc_javax_accessibility_AccessibleState$vtype;

// Class fields structure
struct _jc_javax_accessibility_AccessibleState$fields_struct {
	struct _jc_javax_accessibility_AccessibleState$object	*ACTIVE;
	struct _jc_javax_accessibility_AccessibleState$object	*ARMED;
	struct _jc_javax_accessibility_AccessibleState$object	*BUSY;
	struct _jc_javax_accessibility_AccessibleState$object	*CHECKED;
	struct _jc_javax_accessibility_AccessibleState$object	*COLLAPSED;
	struct _jc_javax_accessibility_AccessibleState$object	*EDITABLE;
	struct _jc_javax_accessibility_AccessibleState$object	*ENABLED;
	struct _jc_javax_accessibility_AccessibleState$object	*EXPANDABLE;
	struct _jc_javax_accessibility_AccessibleState$object	*EXPANDED;
	struct _jc_javax_accessibility_AccessibleState$object	*FOCUSABLE;
	struct _jc_javax_accessibility_AccessibleState$object	*FOCUSED;
	struct _jc_javax_accessibility_AccessibleState$object	*HORIZONTAL;
	struct _jc_javax_accessibility_AccessibleState$object	*ICONIFIED;
	struct _jc_javax_accessibility_AccessibleState$object	*MODAL;
	struct _jc_javax_accessibility_AccessibleState$object	*MULTISELECTABLE;
	struct _jc_javax_accessibility_AccessibleState$object	*MULTI__5fLINE;
	struct _jc_javax_accessibility_AccessibleState$object	*OPAQUE;
	struct _jc_javax_accessibility_AccessibleState$object	*PRESSED;
	struct _jc_javax_accessibility_AccessibleState$object	*RESIZABLE;
	struct _jc_javax_accessibility_AccessibleState$object	*SELECTABLE;
	struct _jc_javax_accessibility_AccessibleState$object	*SELECTED;
	struct _jc_javax_accessibility_AccessibleState$object	*SHOWING;
	struct _jc_javax_accessibility_AccessibleState$object	*SINGLE__5fLINE;
	struct _jc_javax_accessibility_AccessibleState$object	*TRANSIENT;
	struct _jc_javax_accessibility_AccessibleState$object	*VERTICAL;
	struct _jc_javax_accessibility_AccessibleState$object	*VISIBLE;
};
extern _jc_javax_accessibility_AccessibleState$fields_struct _jc_javax_accessibility_AccessibleState$class_fields;

// Constructors
extern void _jc_javax_accessibility_AccessibleState$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_accessibility_AccessibleState$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_accessibility_AccessibleState$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_accessibility_AccessibleState$vmethods {
};

// Vtable
struct _jc_javax_accessibility_AccessibleState$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleBundle$vmethods	javax_accessibility_AccessibleBundle;
	_jc_javax_accessibility_AccessibleState$vmethods	javax_accessibility_AccessibleState;
};

// Vtype
struct _jc_javax_accessibility_AccessibleState$vtype {
	_jc_type			type;
	_jc_javax_accessibility_AccessibleState$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleState$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_accessibility_AccessibleState$refs {
    _jc_javax_accessibility_AccessibleState$sub_refs	javax_accessibility_AccessibleState;
    _jc_javax_accessibility_AccessibleBundle$sub_refs	javax_accessibility_AccessibleBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleState$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_accessibility_AccessibleState$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleBundle$sub_nonrefs	javax_accessibility_AccessibleBundle;
    _jc_javax_accessibility_AccessibleState$sub_nonrefs	javax_accessibility_AccessibleState;
};

// Object instance structure
struct _jc_javax_accessibility_AccessibleState$object {
	_jc_javax_accessibility_AccessibleState$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_accessibility_AccessibleState$vtype	*vtype;
	_jc_javax_accessibility_AccessibleState$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_accessibility_AccessibleState$vtype _jc_javax_accessibility_AccessibleState$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_accessibility_AccessibleState, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_accessibility_AccessibleState$class_object;

#endif	/* _JC_javax_accessibility_AccessibleState_H_ */
